<?php

$lan = array(
'Add new admin' => 'Adicionar novo administrador',
'Administrators' => 'Administradores',
'Find an admin' => 'Encontrar admin',
'Administrators' => 'Administradores',
'Show' => 'Exibir',
'Show' => 'Exibir',
'Show' => 'Exibir',
'Add new admin' => 'Adicionar novo administrador',
'Import list of admins' => 'Importar lista de admins',
'Deleting' => 'Apagando',
'Done' => 'Conclu&iacute;do',
'Admin added' => 'Administrador adicionado',
'Listing admin' => 'Listando administrador',
'Listing admin 1 to 50' => 'Listando admins de 1 a 50',
'found' => 'Encontrado',

);

?>
